@@ -418,6 +418,24 @@ PropertyEditorImpl.prototype.updateGui = function(onlyChanges) {
         }
     }
 
+    // clear custom property group and child (block attributes) groups:
+    // these are always rebuilt:
+    var groupsToClear = [this.customGroup, this.childGroup];
+    for (var gtci=0; gtci<groupsToClear.length; gtci++) {
+        var groupToClear = groupsToClear[gtci];
+        if (!isNull(groupToClear)) {
+            var children = groupToClear.children();
+            for (var i=0; i<children.length; i++) {
+                var child = children[i];
+                if (isOfType(child, QGridLayout)) {
+                    // don't destroy layout:
+                    continue;
+                }
+                children[i].destroy();
+            }
+        }
+    }
+
     var firstEntry = true;
     var gotLayerProperty = false;
     var gotLinetypeScaleProperty = false;
@@ -441,11 +459,15 @@ PropertyEditorImpl.prototype.updateGui = function(onlyChanges) {
             //var propertyTypeId = attributes.getPropertyTypeId();
             var propertyTypeId = RPropertyTypeId.getPropertyTypeId(group, title);
 
+            var onlyChangesProp = onlyChanges;
+
+            // don't use isCustom here:
             if (propertyTypeId.getId()===-1) {
                 // property is custom property
                 // make sure it knows it's titles, etc:
-                propertyTypeId.setCustomPropertyTitle(RSettings.getAppId());
+                propertyTypeId.setCustomPropertyTitle(group);
                 propertyTypeId.setCustomPropertyName(title);
+                onlyChangesProp = false;
             }
 
             //qDebug("isMixed: ", attributes.isMixed());
@@ -522,7 +544,7 @@ PropertyEditorImpl.prototype.updateGui = function(onlyChanges) {
 
             // other properties:
             else {
-                var gridLayout;
+                var gridLayout = undefined;
                 var groupBox = undefined;
                 if (propertyTypeId.isCustom()) {
                     // block reference attributes:
@@ -550,10 +572,11 @@ PropertyEditorImpl.prototype.updateGui = function(onlyChanges) {
                 // add group title and index controls if the property is a list:
                 if (pi===0 && !isNull(gridLayout) && !isNull(groupBox)) {
                     // create group label:
-                    if (!onlyChanges && group.length!==0 &&
-                            // situation with two splines, one with fit points,
-                            // one with control points: no group label for fit points:
-                            attributes.isList()===isArray(value)) {
+                    if (!onlyChangesProp && group.length!==0 &&
+                        // situation with two splines, one with fit points,
+                        // one with control points: no group label for fit points:
+                        attributes.isList()===isArray(value)) {
+
                         var groupLabel = new QLabel(RSettings.translate("REntity", group), groupBox);
                         groupLabel.styleSheet = "margin-bottom:0px;font-weight:bold;";
                         if (!firstEntry) {
@@ -564,7 +587,7 @@ PropertyEditorImpl.prototype.updateGui = function(onlyChanges) {
                     }
 
                     // if property is a list, add list index control:
-                    if (!onlyChanges && attributes.isList()) {
+                    if (!onlyChangesProp && attributes.isList()) {
                         row = gridLayout.rowCount();
                         var indexLabel = new QLabel(qsTr("Index"), groupBox);
                         indexLabel.alignment = Qt.AlignRight | Qt.AlignVCenter;
@@ -596,16 +619,18 @@ PropertyEditorImpl.prototype.updateGui = function(onlyChanges) {
                         controls = undefined;
                     }
                     else {
-                        controls = this.initControls(propertyTypeId, onlyChanges);
+                        controls = this.initControls(propertyTypeId, onlyChangesProp);
                     }
                 }
 
                 // add property name and controls to layout:
-                if (!onlyChanges) {
+                if (!onlyChangesProp) {
                     if (!isNull(controls) && !isNull(gridLayout)) {
                         row = gridLayout.rowCount();
                         var localTitle = title;
-                        if (propertyTypeId.isCustom() && group!==RSettings.getAppId() && propertyTypeId.getCustomPropertyTitle()!=="Attributes") {
+                        if (propertyTypeId.isCustom() && group!==RSettings.getAppId() &&
+                            propertyTypeId.getCustomPropertyTitle()!=="Attributes") {
+
                             var pos = title.indexOf("_");
                             if (pos!==-1) {
                                 localTitle = title.mid(pos+1);
@@ -728,7 +753,7 @@ PropertyEditorImpl.prototype.updateGui = function(onlyChanges) {
     }
 
     // add custom property button:
-    if (!onlyChanges) {
+    //if (!onlyChanges) {
         if (RSettings.isXDataEnabled() && RSettings.getBoolValue("PropertyEditor/AddCustomProperties", true)!==false) {
             var addCustomPropertyButton = new QToolButton(this.widget);
             addCustomPropertyButton.icon = new QIcon(this.basePath + "/AddCustomProperty.svg");
@@ -738,7 +763,7 @@ PropertyEditorImpl.prototype.updateGui = function(onlyChanges) {
             addCustomPropertyButton.clicked.connect(this, "addCustomProperty");
             gridLayoutCustom.addWidget(addCustomPropertyButton, gridLayoutCustom.rowCount(),3, 1,1);
         }
-    }
+    //}
 
     this.widget.updatesEnabled = true;
 };
@@ -938,6 +963,10 @@ PropertyEditorImpl.prototype.initNumberControls = function(objectName, propertyT
         if (attributes.isAngleType()) {
             control.setAngle(true);
         }
+        // TODO: support scale in RMathLineEdit:
+//        if (attributes.isScaleType()) {
+//            control.setScale(true);
+//        }
         control.objectName = objectName;
     }
 
